@@ -13,7 +13,7 @@
 
 ##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
 
-Version = '2.5'
+Version = '2.5-8'
 
 import os
 import sys
@@ -59,7 +59,7 @@ def showMessage(message):
                org.freedesktop.Notifications.SystemNoteDialog \
                string:"%s" uint32:0 string:"OK"' % message)          
 
-def showQuickMessage(message):   
+def showQuickMessage(message):
     ''' Method to display shortly a message to the user. '''
 
     os.system('dbus-send --type=method_call --dest=org.freedesktop.Notifications \
@@ -126,7 +126,7 @@ def getCurrent():
     ##define variables to readout
     global dataVars
     dataVars={}
-    configVars = ['zoom_on_press', 'parallax', 'blurless', 'blurless_saturation', 'taskswitcher', 'zaxisrotation', 'forcerotation', 'tactilepopups']
+    configVars = ['zoom_on_press', 'parallax', 'blurless', 'blurless_saturation', 'thumb_desaturation', 'taskswitcher', 'zaxisrotation', 'forcerotation', 'tactilepopups']
 
     ##readout the variables               
     try:
@@ -158,6 +158,8 @@ def getCurrent():
        fixNeeded = 'true'
     elif 'blurless_saturation' not in dataVars: 
        fixNeeded = 'true'
+    elif 'thumb_desaturation' not in dataVars: 
+       fixNeeded = 'true'
     elif 'taskswitcher' not in dataVars:
        fixNeeded = 'true'
     elif 'zaxisrotation' not in dataVars: 
@@ -253,7 +255,7 @@ class CSSUfeaturesFixConfig(QtGui.QMainWindow):
        
        sys.exit(1)
 
-    def fixConfigVariables(self): ##FIXME: make a loop on variables than this spaghetti code!
+    def fixConfigVariables(self): ##FIXME: make a loop on variables than this spaghetti code!;
        
        if Path == PathSystem:
           configLocation = 'configSystem'
@@ -267,61 +269,60 @@ class CSSUfeaturesFixConfig(QtGui.QMainWindow):
        if 'zoom_on_press' not in dataVars:
           os.system('sudo %s%s addzoom_on_press %s' % (PathApp, updateSettings, configLocation))
           message += 'WARNING: Added the zoom_on_press option..\n'
-          print message
        else:
           print 'zoom_on_press exists!!'
 
        if 'parallax' not in dataVars:
           os.system('sudo %s%s addparallax %s' % (PathApp, updateSettings, configLocation))
           message += 'WARNING: Added the parallax option..\n'
-          print message
        else:
           print 'parallax exists!!'
 
        if 'blurless' not in dataVars:
           os.system('sudo %s%s addblurless %s' % (PathApp, updateSettings, configLocation))
           message += 'WARNING: Added the blurless option..\n'
-          print message
        else:
           print 'blurless exists!!'
                       
        if 'blurless_saturation' not in dataVars:
           os.system('sudo %s%s addblurless_saturation %s' % (PathApp, updateSettings, configLocation))
           message += 'WARNING: Added the blurless_saturation option..\n'
-          print message
        else:
           print 'blurless_saturation exists!!'
+
+       if 'thumb_desaturation' not in dataVars:
+          os.system('sudo %s%s addthumb_desaturation %s' % (PathApp, updateSettings, configLocation))
+          message += 'WARNING: Added the thumb_desaturation option..\n'
+       else:
+          print 'thumb_desaturation exists!!'
                       
        if 'taskswitcher' not in dataVars:
           os.system('sudo %s%s addtaskswitcher %s' % (PathApp, updateSettings, configLocation))
           message += 'WARNING: Added the taskswitcher option..\n'
-          print message
        else:
           print 'taskswitcher exists!!'
                       
        if 'zaxisrotation' not in dataVars:
           os.system('sudo %s%s addzaxisrotation %s' % (PathApp, updateSettings, configLocation))
           message += 'WARNING: Added the zaxisrotation option..\n'
-          print message
        else:
           print 'zaxisrotation exists!!'
                       
        if 'forcerotation' not in dataVars:
           os.system('sudo %s%s addforcerotation %s' % (PathApp, updateSettings, configLocation))
           message += 'WARNING: Added the forcerotation option..\n'
-          print message
        else:
           print 'forcerotation exists!!'
                       
        if 'tactilepopups' not in dataVars:
           os.system('sudo %s%s addtactilepopups %s' % (PathApp, updateSettings, configLocation))
           message += 'WARNING: Added the tactilepopups option..\n'
-          print message
        else:
           print 'tactilepopups exists!!'
 
        message += 'End of fixing\n\n'
        message += 'The application will now exit..'
+       print message
        showMessage(message)
        # getCurrent()
        # copyConfigFile()
@@ -362,7 +363,6 @@ class CSSUfeaturesAbout(QtGui.QMainWindow):
        #awidget.setMinimumSize(470,1000)
        awidget.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
        aboutScrollArea.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
-       #Kinetic scroller is available on Maemo and should be on meego
        try:
           scroller = aboutScrollArea.property("kineticScroller").toPyObject()
           scroller.setEnabled(True)
@@ -409,6 +409,7 @@ class CSSUfeaturesAbout(QtGui.QMainWindow):
        QDesktopServices.openUrl(QUrl('https://bugs.maemo.org'))
 
 class CSSUfeaturesMainWindow(QtGui.QMainWindow):
+
     def __init__(self, parent=None):
        
        ##Build parent user interface
@@ -419,19 +420,21 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
        
        ##Connect the GUI Buttons with actions
-         ##Create Settings
+       
+       ##Create Settings
        QtCore.QObject.connect(self.ui.btnCreateConfig, QtCore.SIGNAL('clicked()'), self.doCreateConfig)
        QtCore.QObject.connect(self.ui.btnSetCurrent, QtCore.SIGNAL('clicked()'), self.doSetCurrent)
        QtCore.QObject.connect(self.ui.btnSetDefault, QtCore.SIGNAL('clicked()'), self.doSetDefault)
        
-         ##Connect Menu Buttons 
+       ##Connect Menu Buttons 
        QtCore.QObject.connect(self.ui.actionQuit, QtCore.SIGNAL('triggered()'), QtGui.qApp, QtCore.SLOT('quit()'))
        QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL('triggered()'), self.showAbout)
        QtCore.QObject.connect(self.ui.actionRestoreDefaults, QtCore.SIGNAL('triggered()'), self.restoreDefaultConfigFile)
        QtCore.QObject.connect(self.ui.actionRebootDevice, QtCore.SIGNAL('triggered()'), self.rebootDevice)
        QtCore.QObject.connect(self.ui.actionAddPowerKeyEntry, QtCore.SIGNAL('triggered()'), self.addPowerKeyEntry)
        QtCore.QObject.connect(self.ui.actionRemovePowerKeyEntry, QtCore.SIGNAL('triggered()'), self.removePowerKeyEntry)
-         ##Enable only the valid menu entry 
+       
+       ##Enable only the valid menu entry 
        if checkFile(PathSystemUi, ConfigSystemUi) == True:
           self.ui.actionAddPowerKeyEntry.setEnabled(False)
        else:
@@ -448,7 +451,7 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
           self.fixConfigFileVariables()
        else:
           self.doSetCurrent()
-          
+
     ##Create Methods
 
     def showAbout(self):
@@ -516,6 +519,7 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
           self.ui.comboBoxZoomPress.setCurrentIndex(int(dataVars['zoom_on_press']))
           self.ui.comboBoxBlurless.setCurrentIndex(int(dataVars['blurless']))
           self.ui.comboBoxBlurlessSaturation.setCurrentIndex(int(dataVars['blurless_saturation']))
+          self.ui.comboBoxThumbDesaturation.setCurrentIndex(int(dataVars['thumb_desaturation']))
           self.ui.comboBoxTaskSwitcher.setCurrentIndex(int(dataVars['taskswitcher']))
           self.ui.comboBoxRotationAxis.setCurrentIndex(int(dataVars['zaxisrotation']))
           self.ui.comboBoxForcedRotation.setCurrentIndex(int(dataVars['forcerotation']))
@@ -568,6 +572,7 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
 
        self.ui.comboBoxBlurless.setCurrentIndex(0)
        self.ui.comboBoxBlurlessSaturation.setCurrentIndex(0)
+       self.ui.comboBoxThumbDesaturation.setCurrentIndex(0)
        self.ui.comboBoxTaskSwitcher.setCurrentIndex(0)
        self.ui.comboBoxRotationAxis.setCurrentIndex(0)
        self.ui.comboBoxForcedRotation.setCurrentIndex(0)
@@ -593,6 +598,7 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
        ##Read GUI.
        Blurless            = self.ui.comboBoxBlurless.currentIndex()
        BlurlessSaturation  = self.ui.comboBoxBlurlessSaturation.currentIndex()
+       ThumbDesaturation   = self.ui.comboBoxThumbDesaturation.currentIndex()
        TaskSwitcher        = self.ui.comboBoxTaskSwitcher.currentIndex()
        RotationAxis        = self.ui.comboBoxRotationAxis.currentIndex()
        ForcedRotation      = self.ui.comboBoxForcedRotation.currentIndex()
@@ -649,6 +655,8 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
              destination.write('forcerotation = %s\n' % ForcedRotation)
           elif Line.startswith("tactilepopups"):
              destination.write('tactilepopups = %s\n' % Tactile)
+          elif Line.startswith("thumb_desaturation"):
+             destination.write('thumb_desaturation = %s\n' % ThumbDesaturation)
           else: 
              destination.write( Line )
        source.close()
@@ -680,6 +688,8 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
                 destination.write('forcerotation = %s\n' % ForcedRotation)
              elif Line.startswith("tactilepopups"):
                 destination.write('tactilepopups = %s\n' % Tactile)
+             elif Line.startswith("thumb_desaturation"):
+                destination.write('thumb_desaturation = %s\n' % ThumbDesaturation)
              else: 
                 destination.write( Line )
           source.close()
@@ -710,7 +720,6 @@ class CSSUfeaturesMain():
     if checkCSSUinstalled() == False:
        message = 'WARNING: The Community SSU is not installed.\nSome features might not work correctly..'
        showMessage(message)
-       #sys.exit(1)
     else:
        pass
      
